[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# FactSet ESG client library for Python

[![API Version](https://img.shields.io/badge/api-v1.7.0-blue)](https://developer.factset.com/api-catalog/factset-esg-api)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.FactSetESG)](https://pypi.org/project/fds.sdk.FactSetESG/)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

FactSet ESG (powered by FactSet Truvalue Labs) applies machine learning to uncover risks and opportunities from companies' Environmental, Social and Governance (ESG) behavior, which are aggregated and categorized into continuously updated, material ESG scores. The service focuses on company ESG behavior from external sources and includes both positive and negative events that go beyond traditional sources of ESG risk data.<p> FactSet ESG extracts, analyzes, and generates scores from millions of documents each month collected from more than 100,000 data sources in over 30 languages. Sources include news, trade journals, NGOs, watchdog groups, trade blogs, industry reports and social media. Products deliver investable insights by revealing value and risk factors from unstructured data at the speed of current events.</p>


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.7.0
- SDK version: 1.3.5
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.FactSetESG==1.3.5
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.FactSetESG==1.3.5
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.FactSetESG
from fds.sdk.FactSetESG.api import articles_api
from fds.sdk.FactSetESG.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.FactSetESG.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.FactSetESG.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.FactSetESG.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = articles_api.ArticlesApi(api_client)
    ids = ["AAPL-USA"] # [str] | Security or Entity identifiers. FactSet Identifiers, tickers, CUSIP and SEDOL are accepted input. <p>***ids limit** =  1500 per request*</p> *<p>Make note, GET Method URL request lines are also limited to a total  length of 8192 bytes (8KB). In cases where the service allows for thousands of ids, which may lead to exceeding this request line limit of 8KB, its advised for any requests with large request lines to be requested through the respective \"POST\" method.</p>* 
    start_date = "2021-01-01" # str | The start date requested for a given date range in YYYY-MM-DD format. The input start date must be before the input end date. Future dates (T+1) are not accepted in this endpoint. 
    end_date = "2021-10-30" # str | The end date requested for a given date range in YYYY-MM-DD format. The input end date must be after the input start date. Future dates (T+1) are not accepted in this endpoint. 
    date_of = "PUBLICATION" # str | Date of Publication or Ingestion   * **Publication:**  use for startDate and endDate the articles publication date   * **Ingestion:**  use for startDate and endDate the articles TVL first processing date     (optional) if omitted the server will use the default value of "PUBLICATION"
    fields = ["datePub"] # [str] | Request available Articles data fields to be included in the response.  Default is all fields. _fsymId_ and _articleId_ are always included.    <h3>Common Fields</h3>    |field|description|   |---|---|   |fsymId|Factset Regional Security Identifier|   |articleId|Unique ID of the article assigned by Truvalue|               <h3>Articles Fields</h3>     |field|description|   |---|---|   |datePub|Publication date of the article in YYYY-MM-DD format|   |title|Title of the article|   |source|Source of the article|   |categories|categories assigned by Truvalue|   |bullets|AI-generated bullet point summary for each article. Note, including bullets increases response size drastically|   |author|Author of the article|   |url|URL of the article|   |language|Language code of the article|   |dateIngestion|Date of TVL article ingestion and processing|   |orgName| Organization name assigned by Truvalue|   |orgId| Unique identifier assigned by Truvalue that is applied on an organization level   (optional)
    categories = ["AIRQUALITY","BUSINESSETHICS","HUMANRIGHTSANDCOMRELS"] # [str] | Comma seperated list of one or more SASB category names as described below. The default value is **ALLCATEGORIES**.   ### SASB Categories |**SASB Category Inputs**|**Description**| |---|---| |**ALLCATEGORIES**|**All Categories** - Provides articles tagged to all 26 categories of SASB. Equivalent to providing all 26 categories |**SASBMATERIALITY**|**SASBMateriality** - provides articles tagged to material categories according to SASB's materiality framework. When provided, only material categories for each company is fetched| |**ACCESSANDAFFORDABILITY**|**Access and Affordability** - The category addresses a company's ability to ensure broad access to its products and services, specifically in the context of underserved markets and/or population groups. It includes the management of issues related to universal needs, such as the accessibility and affordability of health care, financial services, utilities , education, and telecommunications.| |**AIRQUALITY**|**Air Quality** - the category addresses management of air quality impacts resulting from stationary (e.g., factories, power plants) and mobile sources (e.g., trucks, delivery vehicles, planes) as well as industrial emissions. Relevant airborne pollutants include, but are not limited to, oxides of nitrogen (NOx), oxides of sulfur (SOx), volatile organic compounds (VOCs), heavy metals, particulate matter, and chlorofluorocarbons. The category does not include GHG emissions, which are addressed in a separate category.| |**BUSINESSETHICS**|**Business Ethics** - the category addresses the company's approach to managing risks and opportunities surrounding ethical conduct of business, including fraud, corruption, bribery and facilitation payments, fiduciary responsibilities, and other behavior that may have an ethical component. This includes sensitivity to business norms and standards as they shift over time, jurisdiction, and culture. It addresses the company's ability to provide services that satisfy the highest professional and ethical standards of the industry, which means to avoid conflicts of interest, misrepresentation, bias, and negligence through training employees adequately and implementing policies and procedures to ensure employees provide services free from bias and error.| |**BUSMODELRESILIENCE**|**Business Model Resilience** - the category addresses an industry's capacity to manage risks and opportunities associated with incorporating social, environmental, and political transitions into long-term business model planning. This includes responsiveness to the transition to a low-carbon and climate-constrained economy, as well as growth and creation of new markets among unserved and underserved socioeconomic populations. The category highlights industries in which evolving environmental and social realities may challenge companies to fundamentally adapt or may put their business models at risk.| |**COMPETITIVEBEHAVIOR**|**Competitive Behavior** - the category covers social issues associated with existence of monopolies, which may include, but are not limited to, excessive prices, poor quality of service, and inefficiencies. It addresses a company's management of legal and social expectation around monopolistic and anti-competitive practices, including issues related to bargaining power, collusion, price fixing or manipulation, and protection of patents and intellectual property (IP).| |**CRITINCIDENTRISKMGT**|**Critical Incident Risk Management** - the category addresses the company's use of management systems and scenario planning to identify, understand, and prevent or minimize the occurrence of low-probability, high-impact accidents and emergencies with significant potential environmental and social externalities. It relates to the culture of safety at a company, its relevant safety management systems and technological controls, the potential human, environmental, and social implications of such events occurring, and the long-term effects to an organization, its workers, and society should these events occur.| |**CUSTOMERPRIVACY**|**Customer Privacy** - the category addresses management of risks related to the use of personally identifiable information (PII) and other customer or user data for secondary purposes including but not limited to marketing through affiliates and non-affiliates. The scope of the category includes social issues that may arise from a company's approach to collecting data, obtaining consent (e.g., opt-in policies), managing user and customer expectations regarding how their data is used, and managing evolving regulation. It excludes social issues arising from cybersecurity risks, which are covered in a separate category.| |**CUSTWELFARE**|**Customer Welfare** - the category addresses customer welfare concerns over issues including, but not limited to, health and nutrition of foods and beverages, antibiotic use in animal production, and management of controlled substances. The category addresses the company's ability to provide consumers with manufactured products and services that are aligned with societal expectations. It does not include issues directly related to quality and safety malfunctions of manufactured products and services, but instead addresses qualities inherent to the design and delivery of products and services where customer welfare may be in question. The scope of the category also captures companies' ability to prevent counterfeit products.| |**DATASECURITY**|**Data Security** - the category addresses management of risks related to collection, retention, and use of sensitive, confidential, and/or proprietary customer or user data. It includes social issues that may arise from incidents such as data breaches in which personally identifiable information (PII) and other user or customer data may be exposed. It addresses a company's strategy, policies, and practices related to IT infrastructure, staff training, record keeping, cooperation with law enforcement, and other mechanisms used to ensure security of customer or user data.| |**ECOLOGICALIMPACTS**|**Ecological Impacts** - the category addresses management of the company's impacts on ecosystems and biodiversity through activities including, but not limited to, land use for exploration, natural resource extraction, and cultivation, as well as project development, construction, and siting. The impacts include, but are not limited to, biodiversity loss, habitat destruction, and deforestation at all stages – planning, land acquisition, permitting, development, operations, and site remediation. The category does not cover impacts of climate change on ecosystems and biodiversity.| |**EMPENGDIVANDINC**|**Employee Engagement Diversity and Inclusion** - the category addresses a company's ability to ensure that its culture and hiring and promotion practices embrace the building of a diverse and inclusive workforce that reflects the makeup of local talent pools and its customer base. It addresses the issues of discriminatory practices on the bases of race, gender, ethnicity, religion, sexual orientation, and other factors.| |**EMPHEALTHANDSAFETY**|**Employee Health and Safety** - the category addresses a company's ability to create and maintain a safe and healthy workplace environment that is free of injuries, fatalities, and illness (both chronic and acute). It is traditionally accomplished through implementing safety management plans, developing training requirements for employees and contractors, and conducting regular audits of their own practices as well as those of their subcontractors. The category further captures how companies ensure physical and mental health of workforce through technology, training, corporate culture, regulatory compliance, monitoring and testing, and personal protective equipment.| |**ENERGYMGT**|**Energy Management** - the category addresses environmental impacts associated with energy consumption. It addresses the company's management of energy in manufacturing and/or for provision of products and services derived from utility providers (grid energy) not owned or controlled by the company. More specifically, it includes management of energy efficiency and intensity, energy mix, as well as grid reliance. Upstream (e.g., suppliers) and downstream (e.g., product use) energy use is not included in the scope.| |**GHGEMISSIONS**|**Greenhouse Gas Emissions** - the category addresses direct (Scope 1) greenhouse gas (GHG) emissions that a company generates through its operations. This includes GHG emissions from stationary (e.g., factories, power plants) and mobile sources (e.g., trucks, delivery vehicles, planes), whether a result of combustion of fuel or non-combusted direct releases during activities such as natural resource extraction, power generation, land use, or biogenic processes. The category further includes management of regulatory risks, environmental compliance, and reputational risks and opportunities, as they related to direct GHG emissions. The seven GHGs covered under the Kyoto Protocol are included within the category— carbon dioxide (CO2 ), methane (CH4), nitrous oxide (N2O), hydrofluorocarbons (HFCs), perfluorocarbons (PFCs), sulfur hexafluoride (SF6), and nitrogen trifluoride (NF3).| |**HUMANRIGHTSANDCOMRELS**|**Human Rights and Community Relations** - the category addresses management of the relationship between businesses and the communities in which they operate, including, but not limited to, management of direct and indirect impacts on core human rights and the treatment of indigenous peoples. More specifically, such management may cover socio-economic community impacts, community engagement, environmental justice, cultivation of local workforces, impact on local businesses, license to operate, and environmental/social impact assessments. The category does not include environmental impacts such as air pollution or waste which, although they may impact the health and safety of members of local communities, are addressed in separate categories.| |**LABORPRACTICES**|**Labor Practices** - the category addresses the company's ability to uphold commonly accepted labor standards in the workplace, including compliance with labor laws and internationally accepted norms and standards. This includes, but is not limited to, ensuring basic human rights related to child labor, forced or bonded labor, exploitative labor, fair wages and overtime pay, and other basic workers' rights. It also includes minimum wage policies and provision of benefits, which may influence how a workforce is attracted, retained, and motivated. The category further addresses a company's relationship with organized labor and freedom of association.| |**MGTOFLEGALANDREGENV**|**Management of the Legal and Regulatory Environment** - the category addresses a company's approach to engaging with regulators in cases where conflicting corporate and public interests may have the potential for long-term adverse direct or indirect environmental and social impacts. The category addresses a company's level of reliance upon regulatory policy or monetary incentives (such as subsidies and taxes), actions to influence industry policy (such as through lobbying), overall reliance on a favorable regulatory environment for business competitiveness, and ability to comply with relevant regulations. It may relate to the alignment of management and investor views of regulatory engagement and compliance at large.| |**MATSOURCINGANDEFF**|**Materials Sourcing and Efficiency** - the category addresses issues related to the resilience of materials supply chains to impacts of climate change and other external environmental and social factors. It captures the impacts of such external factors on operational activity of suppliers, which can further affect availability and pricing of key resources. It addresses a company's ability to manage these risks through product design, manufacturing, and end-of-life management, such as by using of recycled and renewable materials, reducing the use of key materials (dematerialization), maximizing resource efficiency in manufacturing, and making R&D investments in substitute materials. Additionally, companies can manage these issues by screening, selection, monitoring, and engagement with suppliers to ensure their resilience to external risks. It does not address issues associated with environmental and social externalities created by operational activity of individual suppliers, which is covered in a separate category.| |**PHYIMPACTSOFCLIMATECHG**|**Physical Impacts of Climate Change** - the category addresses the company's ability to manage risks and opportunities associated with direct exposure of its owned or controlled assets and operations to actual or potential physical impacts of climate change. It captures environmental and social issues that may arise from operational disruptions due to physical impacts of climate change. It further captures socioeconomic issues resulting from companies failing to incorporate climate change consideration in products and services sold, such as insurance policies and mortgages. The category relates to the company's ability to adapt to increased frequency and severity of extreme weather, shifting climate, sea level risk, and other expected physical impacts of climate change. Management may involve enhancing resiliency of physical assets and/or surrounding infrastructure as well as incorporation of climate change-related considerations into key business activities (e.g., mortgage and insurance underwriting, planning and development of real estate projects).| |**PDANDLIFECYCLEMGT**|**Product Design and Lifecycle Management** - the category addresses incorporation of environmental, social, and governance (ESG) considerations in characteristics of products and services provided or sold by the company. It includes, but is not limited to, managing the lifecycle impacts of products and services, such as those related to packaging, distribution, use-phase resource intensity, and other environmental and social externalities that may occur during their use-phase or at the end of life. The category captures a company's ability to address customer and societal demand for more sustainable products and services as well as to meet evolving environmental and social regulation. It does not address direct environmental or social impacts of the company's operations nor does it address health and safety risks to consumers from product use, which are covered in other categories.| |**PRODQUALITYANDSFTY**|**Product Quality and Safety** - the category addresses issues involving unintended characteristics of products sold or services provided that may create health or safety risks to end-users. It addresses a company's ability to offer manufactured products and/or services that meet customer expectations with respect to their health and safety characteristics. It includes, but is not limited to, issues involving liability, management of recalls and market withdrawals, product testing, and chemicals/content/ ingredient management in products.| |**SELLPRACANDPRODLABEL**|**Selling Practices and Product Labeling** - the category addresses social issues that may arise from a failure to manage the transparency, accuracy, and comprehensibility of marketing statements, advertising, and labeling of products and services. It includes, but is not limited to, advertising standards and regulations, ethical and responsible marketing practices, misleading or deceptive labeling, as well as discriminatory or predatory selling and lending practices. This may include deceptive or aggressive selling practices in which incentive structures for employees could encourage the sale of products or services that are not in the best interest of customers or clients.| |**SUPPLYCHAINMGT**|**Supply Chain Management** - the category addresses management of environmental, social, and governance (ESG) risks within a company's supply chain. It addresses issues associated with environmental and social externalities created by suppliers through their operational activities. Such issues include, but are not limited to, environmental responsibility, human rights, labor practices, and ethics and corruption. Management may involve screening, selection, monitoring, and engagement with suppliers on their environmental and social impacts. The category does not address the impacts of external factors – such as climate change and other environmental and social factors – on suppliers' operations and/or on the availability and pricing of key resources, which is covered in a separate category.| |**SYSTEMICRISKMGT**|**Systemic Risk Management** - the category addresses the company's contributions to, or management of systemic risks resulting from large-scale weakening or collapse of systems upon which the economy and society depend. This includes financial systems, natural resource systems, and technological systems. It addresses the mechanisms a company has in place to reduce its contributions to systemic risks and to improve safeguards that may mitigate the impacts of systemic failure. For financial institutions, the category also captures the company's ability to absorb shocks arising from financial and economic stress and meet stricter regulatory requirements related to the complexity and interconnectedness of companies in the industry.| |**WASTEANDHZRDMATSMGT**|**Waste and Hazardous Materials Management** - the category addresses environmental issues associated with hazardous and non-hazardous waste generated by companies. It addresses a company's management of solid wastes in manufacturing, agriculture, and other industrial processes. It covers treatment, handling, storage, disposal, and regulatory compliance. The category does not cover emissions to air or wastewater, nor does it cover waste from end-of-life of products, which are addressed in separate categories.| |**WATERANDWASTEWATERMGT**|**Water and Wastewater Management** - the category addresses a company's water use, water consumption, wastewater generation, and other impacts of operations on water resources, which may be influenced by regional differences in the availability and quality of and competition for water resources. More specifically, it addresses management strategies including, but not limited to, water efficiency, intensity, and recycling. Lastly, the category also addresses management of wastewater treatment and discharge, including groundwater and aquifer pollution.|  (optional) if omitted the server will use the default value of ["ALLCATEGORIES"]

    try:
        # Request articles tagged with SASB lens categories from 2016-01-01 to previous day.
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.get_sasb_articles(ids, start_date, end_date, date_of=date_of, fields=fields, categories=categories)

        pprint(api_response)
    except fds.sdk.FactSetESG.ApiException as e:
        print("Exception when calling ArticlesApi->get_sasb_articles: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Request articles tagged with SASB lens categories from 2016-01-01 to previous day.
    #     api_response, http_status_code, response_headers = api_instance.get_sasb_articles_with_http_info(ids, start_date, end_date, date_of=date_of, fields=fields, categories=categories)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.FactSetESG.ApiException as e:
    #     print("Exception when calling ArticlesApi->get_sasb_articles: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Request articles tagged with SASB lens categories from 2016-01-01 to previous day.
    #     async_result = api_instance.get_sasb_articles_async(ids, start_date, end_date, date_of=date_of, fields=fields, categories=categories)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.FactSetESG.ApiException as e:
    #     print("Exception when calling ArticlesApi->get_sasb_articles: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Request articles tagged with SASB lens categories from 2016-01-01 to previous day.
    #     async_result = api_instance.get_sasb_articles_with_http_info_async(ids, start_date, end_date, date_of=date_of, fields=fields, categories=categories)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.FactSetESG.ApiException as e:
    #     print("Exception when calling ArticlesApi->get_sasb_articles: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.FactSetESG

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.FactSetESG.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.FactSetESG

configuration = fds.sdk.FactSetESG.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.FactSetESG

configuration = fds.sdk.FactSetESG.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.FactSetESG

configuration = fds.sdk.FactSetESG.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/content*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ArticlesApi* | [**get_sasb_articles**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/ArticlesApi.md#get_sasb_articles) | **GET** /factset-esg/v1/sasb-articles | Request articles tagged with SASB lens categories from 2016-01-01 to previous day.
*ArticlesApi* | [**get_sasb_articles_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/ArticlesApi.md#get_sasb_articles_for_list) | **POST** /factset-esg/v1/sasb-articles | Request articles tagged with SASB lens categories from 2016-01-01 to previous day
*SASBApi* | [**get_sasb_ranks**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SASBApi.md#get_sasb_ranks) | **GET** /factset-esg/v1/sasb-ranks | Gets ESG Rankings for a requested list of ids and dates.
*SASBApi* | [**get_sasb_ranks_post**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SASBApi.md#get_sasb_ranks_post) | **POST** /factset-esg/v1/sasb-ranks | Get ESG Ranks for a large list of ids and specified date range.
*SASBApi* | [**get_sasb_scores**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SASBApi.md#get_sasb_scores) | **GET** /factset-esg/v1/sasb-scores | Gets short-term, long-term, and momentum scores based on the 26 ESG categories defined by the Sustainability Accounting Standards Board (SASB).
*SASBApi* | [**get_sasb_scores_all**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SASBApi.md#get_sasb_scores_all) | **GET** /factset-esg/v1/sasb-scores-all | Gets a flat key value array of scores for named categories of the input scoreType(s).
*SASBApi* | [**get_sasb_scores_all_post**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SASBApi.md#get_sasb_scores_all_post) | **POST** /factset-esg/v1/sasb-scores-all | Gets a flat key value array of scores for named categories of the input score type(s).
*SASBApi* | [**get_sasb_scores_post**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SASBApi.md#get_sasb_scores_post) | **POST** /factset-esg/v1/sasb-scores | For a large list of ids, gets short-term, long-term, and momentum scores based on the 26 ESG categories defined by the Sustainability Accounting Standards Board (SASB).
*SpotlightsApi* | [**get_sasb_spotlights**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SpotlightsApi.md#get_sasb_spotlights) | **GET** /factset-esg/v1/sasb-spotlights | Gets Spotlight data for the most important positive and negative ESG events to enable timely and systematic trading strategies and portfolio management
*SpotlightsApi* | [**get_sasb_spotlights_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SpotlightsApi.md#get_sasb_spotlights_for_list) | **POST** /factset-esg/v1/sasb-spotlights | Gets Spotlight data for the most important positive and negative ESG events to enable timely and systematic trading strategies and portfolio management


## Documentation For Models

 - [ArticlesFields](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/ArticlesFields.md)
 - [Calendar](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/Calendar.md)
 - [Categories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/Categories.md)
 - [DateOf](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/DateOf.md)
 - [ErrorResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/ErrorResponse.md)
 - [ErrorResponseSubErrors](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/ErrorResponseSubErrors.md)
 - [FieldsSasbSpotlights](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/FieldsSasbSpotlights.md)
 - [Frequency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/Frequency.md)
 - [Ids](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/Ids.md)
 - [PaiIds](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/PaiIds.md)
 - [RankCategories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/RankCategories.md)
 - [SasbArticle](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbArticle.md)
 - [SasbArticlesCategories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbArticlesCategories.md)
 - [SasbArticlesRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbArticlesRequest.md)
 - [SasbArticlesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbArticlesResponse.md)
 - [SasbRanks](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbRanks.md)
 - [SasbRanksRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbRanksRequest.md)
 - [SasbRanksResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbRanksResponse.md)
 - [SasbScoreTypes](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbScoreTypes.md)
 - [SasbScores](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbScores.md)
 - [SasbScoresAll](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbScoresAll.md)
 - [SasbScoresAllRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbScoresAllRequest.md)
 - [SasbScoresAllResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbScoresAllResponse.md)
 - [SasbScoresRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbScoresRequest.md)
 - [SasbScoresResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbScoresResponse.md)
 - [SasbSpotlightsCategories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbSpotlightsCategories.md)
 - [SasbSpotlightsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SasbSpotlightsRequest.md)
 - [Spotlights](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/Spotlights.md)
 - [SpotlightsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetESG/v1/docs/SpotlightsResponse.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.FactSetESG.apis and fds.sdk.FactSetESG.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.FactSetESG.api.default_api import DefaultApi`
- `from fds.sdk.FactSetESG.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.FactSetESG
from fds.sdk.FactSetESG.apis import *
from fds.sdk.FactSetESG.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

